# Ascend Community

Welcome to the Ascend Community GitHub repository!

## Structure

This repository is organized into the following directories:

| Directory | Description |
|---|---|
| [`projects`](projects/) | Ascend Project templates. |

## Internal

TODO: words
